@@ -31,7 +31,15 @@ c
            else
                 tanh=(1.d0 - cost)/sint
            endif
-           eta=-log(tanh)
+           if(tanh .le. 0.0) then
+              if( cost .gt. 0.) then
+                 eta = 20.
+              else
+                 eta = -20.
+              endif
+           else
+              eta=-log(tanh)
+           endif
        end
 
 
